# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import enum

import winrt.system
from winrt import _winrt_windows_phone_media_devices

__all__ = [
    "AudioRoutingEndpoint",
    "AvailableAudioRoutingEndpoints",
    "AudioRoutingManager",
]

class AudioRoutingEndpoint(enum.IntEnum):
    DEFAULT = 0
    EARPIECE = 1
    SPEAKERPHONE = 2
    BLUETOOTH = 3
    WIRED_HEADSET = 4
    WIRED_HEADSET_SPEAKER_ONLY = 5
    BLUETOOTH_WITH_NOISE_AND_ECHO_CANCELLATION = 6
    BLUETOOTH_PREFERRED = 7

class AvailableAudioRoutingEndpoints(enum.IntFlag):
    NONE = 0
    EARPIECE = 0x1
    SPEAKERPHONE = 0x2
    BLUETOOTH = 0x4

AudioRoutingManager = _winrt_windows_phone_media_devices.AudioRoutingManager
